@@ -2,24 +2,26 @@ package FFI::ExtractSymbols::Windows;
 
 use strict;
 use warnings;
-use FFI::ExtractSymbols::ConfigData;
+use File::ShareDir::Dist ();
 use File::Which qw( which );
 
+my $config = File::ShareDir::Dist::dist_config('FFI-ExtractSymbols');
+
 # ABSTRACT: Windows (and Cygwin) implementation for FFI::ExtractSymbols
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 
 return 1 if FFI::ExtractSymbols->can('extract_symbols') || $^O !~ /^(MSWin32|cygwin)$/;
 
 my $dumpbin = which('dumpbin');
-$dumpbin ||= FFI::ExtractSymbols::ConfigData->config('exe')->{dumpbin};
+$dumpbin ||= $config->{'exe'}->{dumpbin};
 
 if($dumpbin)
 {
   # convert path to dumpbin to a spaceless version if it has
   # spaces
   $dumpbin = Win32::GetShortPathName($dumpbin) if $dumpbin =~ /\s/;
-  
+
   # use forward slashes
   $dumpbin =~ s{\\}{/}g;
 
@@ -33,17 +35,17 @@ if($dumpbin)
   {
     my($libpath, %callbacks) = @_;
     $callbacks{$_} ||= sub {} for qw( export code data );
-    
+
     # dumpbin requires a Windows path, not a POSIX one if you
     # are running under cygwin
     $libpath = Cygwin::posix_to_win_path($libpath) if $^O eq 'cygwin';
-    
+
     # convert path to library to a spaceless version if it has spaces
     $libpath = Win32::GetShortPathName($libpath) if $libpath =~ /\s/;
-    
+
     # use forward slashes
     $libpath =~ s{\\}{/}g;
-    
+
     foreach my $line (`$dumpbin /exports $libpath`)
     {
       # we do not differentiate between code and data
@@ -55,7 +57,7 @@ if($dumpbin)
         $callbacks{code}  ->($symbol, $symbol);
       }
     }
-    
+
     ();
   };
 }
@@ -79,7 +81,7 @@ FFI::ExtractSymbols::Windows - Windows (and Cygwin) implementation for FFI::Extr
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 DESCRIPTION
 
